#!/bin/sh

prefix=/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_986mfkmmsv/croot/jemalloc_1678115288689/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place
exec_prefix=/var/folders/nz/j6p8yfhx1mv_0grj5xl4650h0000gp/T/abs_986mfkmmsv/croot/jemalloc_1678115288689/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_place
libdir=${exec_prefix}/lib

DYLD_INSERT_LIBRARIES=${libdir}/libjemalloc.2.dylib
export DYLD_INSERT_LIBRARIES
exec "$@"
